body {
  background: #e0e0e0;
  text-align: center;
  min-height: 100vh;
  display: block;
  font-family: sans-serif;
  padding: 1em;
  font-size: 1.2em;
  line-height: 120%;
}

.heading, .subheading {
  padding: 20px;
  color: black;
  text-align: center;
}

.subsubheading {
  padding: 5px;
  border-radius: 5px;
  background: #990000;
  margin: 1em 15vw;
  color: white;
}

.logo {
  height: 10em;
}

form {
    text-align: center;
    display: block;
    margin-left: auto;
    margin-right: auto;
    width: 80vw;
    padding: 2em;
}

.value-element {
  font-weight: bold;
}

.hidden {
    display: none;
    height: 0;
    font-size: 0.1em;
    color: rgba(0, 0, 0, 0);
}

@media (max-width: 1000px) and (orientation: landscape) {

  div.chart-container {
    position: relative;
    width: 80vw;
    margin-left: auto;
    margin-right: auto;
  }

}

@media (max-width: 1000px) and (orientation: portrait) {

  div.chart-container {
    position: relative;
    width: 800px;
    margin-left: auto;
    margin-right: auto;
  }

}

@media (min-width: 1000px) {

  div.chart-container {
    position: relative;
    margin: 0 10vw;
  }

}
